Fast-NMS
======

This folder contains an implementation of Fast-NMS [[1]](#fast_nms-1).

Sources
------
Large parts of code are taken from [here](https://github.com/Zzh-tju/CIoU) with modifications to make it compatible with OpenDR specifications. The original code is licensed under the GNU General Public License v3.0:

```
This folder contains code from the CIoU distribution (https://github.com/Zzh-tju/CIoU).
Copyright (c) 2020 Zheng, Zhaohui.

This program is free software: you can redistribute it and/or modify  
it under the terms of the GNU General Public License as published by  
the Free Software Foundation, version 3.

This program is distributed in the hope that it will be useful, but 
WITHOUT ANY WARRANTY; without even the implied warranty of 
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
General Public License for more details.

You should have received a copy of the GNU General Public License 
along with this program. If not, see <http://www.gnu.org/licenses/>.
```

<a name="fast_nms-1" href="https://arxiv.org/abs/1904.02689">[1]</a> YOLACT: Real-time Instance Segmentation,
[ArXiv](https://arxiv.org/abs/1904.02689).
